Module logical

Module logical 

Create test scenarios

Structs

Execution
Logical execution plan that outlines which user type to spawn during runtime and under which Executor.
Rate
Rate of iteration.
Scenario
Named collection of executions which should run in parallel to each other.

Enums

Executor
Executor type that is to be used within an execution.